/**
* Recipes service.
* @module com.spoonacular.client/com.spoonacular/RecipesApi
* @version 1.1
*/
export default class RecipesApi {
    /**
    * Constructs a new RecipesApi.
    * @alias module:com.spoonacular.client/com.spoonacular/RecipesApi
    * @class
    * @param {module:com.spoonacular.client/ApiClient} [apiClient] Optional API client implementation to use,
    * default to {@link module:com.spoonacular.client/ApiClient#instance} if unspecified.
    */
    constructor(apiClient?: any);
    apiClient: any;
    /**
     * Callback function to receive the result of the analyzeARecipeSearchQuery operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~analyzeARecipeSearchQueryCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/AnalyzeARecipeSearchQuery200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Analyze a Recipe Search Query
     * Parse a recipe search query to find out its intention.
     * @param {String} q The recipe search query.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~analyzeARecipeSearchQueryCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/AnalyzeARecipeSearchQuery200Response}
     */
    analyzeARecipeSearchQuery(q: string, callback: any): any;
    /**
     * Callback function to receive the result of the analyzeRecipeInstructions operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~analyzeRecipeInstructionsCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/AnalyzeRecipeInstructions200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Analyze Recipe Instructions
     * This endpoint allows you to break down instructions into atomic steps. Furthermore, each step will contain the ingredients and equipment required. Additionally, all ingredients and equipment from the recipe's instructions will be extracted independently of the step they're used in.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~analyzeRecipeInstructionsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/AnalyzeRecipeInstructions200Response}
     */
    analyzeRecipeInstructions(opts: {
        contentType: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the autocompleteRecipeSearch operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~autocompleteRecipeSearchCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:com.spoonacular.client/com.spoonacular.client.model/AutocompleteRecipeSearch200ResponseInner>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Autocomplete Recipe Search
     * Autocomplete a partial input to suggest possible recipe names.
     * @param {Object} opts Optional parameters
     * @param {String} opts.query The (natural language) search query.
     * @param {Number} opts.number The maximum number of items to return (between 1 and 100). Defaults to 10. (default to 10)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~autocompleteRecipeSearchCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:com.spoonacular.client/com.spoonacular.client.model/AutocompleteRecipeSearch200ResponseInner>}
     */
    autocompleteRecipeSearch(opts: {
        query: string;
        number: number;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the classifyCuisine operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~classifyCuisineCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/ClassifyCuisine200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Classify Cuisine
     * Classify the recipe's cuisine.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~classifyCuisineCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/ClassifyCuisine200Response}
     */
    classifyCuisine(opts: {
        contentType: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the computeGlycemicLoad operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~computeGlycemicLoadCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/ComputeGlycemicLoad200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Compute Glycemic Load
     * Retrieve the glycemic index for a list of ingredients and compute the individual and total glycemic load.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/ComputeGlycemicLoadRequest} computeGlycemicLoadRequest
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.language The language of the input. Either 'en' or 'de'.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~computeGlycemicLoadCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/ComputeGlycemicLoad200Response}
     */
    computeGlycemicLoad(computeGlycemicLoadRequest: any, opts: {
        language: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the convertAmounts operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~convertAmountsCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/ConvertAmounts200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Convert Amounts
     * Convert amounts like \"2 cups of flour to grams\".
     * @param {String} ingredientName The ingredient which you want to convert.
     * @param {Number} sourceAmount The amount from which you want to convert, e.g. the 2.5 in \"2.5 cups of flour to grams\".
     * @param {String} sourceUnit The unit from which you want to convert, e.g. the grams in \"2.5 cups of flour to grams\". You can also use \"piece\", e.g. \"3.4 oz tomatoes to piece\"
     * @param {String} targetUnit The unit to which you want to convert, e.g. the grams in \"2.5 cups of flour to grams\". You can also use \"piece\", e.g. \"3.4 oz tomatoes to piece\"
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~convertAmountsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/ConvertAmounts200Response}
     */
    convertAmounts(ingredientName: string, sourceAmount: number, sourceUnit: string, targetUnit: string, callback: any): any;
    /**
     * Callback function to receive the result of the createRecipeCard operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~createRecipeCardCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/CreateRecipeCard200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Create Recipe Card
     * Generate a recipe card for a recipe.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~createRecipeCardCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/CreateRecipeCard200Response}
     */
    createRecipeCard(opts: {
        contentType: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the equipmentByIDImage operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~equipmentByIDImageCallback
     * @param {String} error Error message, if any.
     * @param {Object} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Equipment by ID Image
     * Visualize a recipe's equipment list as an image.
     * @param {Number} id The recipe id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~equipmentByIDImageCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Object}
     */
    equipmentByIDImage(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the extractRecipeFromWebsite operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~extractRecipeFromWebsiteCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeInformation200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Extract Recipe from Website
     * This endpoint lets you extract recipe data such as title, ingredients, and instructions from any properly formatted Website.
     * @param {String} url The URL of the recipe page.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.forceExtraction If true, the extraction will be triggered whether we already know the recipe or not. Use this only if information is missing as this operation is slower.
     * @param {Boolean} opts.analyze If true, the recipe will be analyzed and classified resolving in more data such as cuisines, dish types, and more.
     * @param {Boolean} opts.includeNutrition Include nutrition data in the recipe information. Nutrition data is per serving. If you want the nutrition data for the entire recipe, just multiply by the number of servings. (default to false)
     * @param {Boolean} opts.includeTaste Whether taste data should be added to correctly parsed ingredients. (default to false)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~extractRecipeFromWebsiteCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeInformation200Response}
     */
    extractRecipeFromWebsite(url: string, opts: {
        forceExtraction: boolean;
        analyze: boolean;
        includeNutrition: boolean;
        includeTaste: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the getAnalyzedRecipeInstructions operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getAnalyzedRecipeInstructionsCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetAnalyzedRecipeInstructions200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Get Analyzed Recipe Instructions
     * Get an analyzed breakdown of a recipe's instructions. Each step is enriched with the ingredients and equipment required.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.stepBreakdown Whether to break down the recipe steps even more.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getAnalyzedRecipeInstructionsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetAnalyzedRecipeInstructions200Response}
     */
    getAnalyzedRecipeInstructions(id: number, opts: {
        stepBreakdown: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the getRandomRecipes operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRandomRecipesCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRandomRecipes200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Get Random Recipes
     * Find random (popular) recipes. If you need to filter recipes by diet, nutrition etc. you might want to consider using the complex recipe search endpoint and set the sort request parameter to random.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.limitLicense Whether the recipes should have an open license that allows display with proper attribution. (default to true)
     * @param {String} opts.tags The tags (can be diets, meal types, cuisines, or intolerances) that the recipe must have.
     * @param {Number} opts.number The maximum number of items to return (between 1 and 100). Defaults to 10. (default to 10)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRandomRecipesCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRandomRecipes200Response}
     */
    getRandomRecipes(opts: {
        limitLicense: boolean;
        tags: string;
        number: number;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipeEquipmentByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeEquipmentByIDCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeEquipmentByID200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Equipment by ID
     * Get a recipe's equipment list.
     * @param {Number} id The item's id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeEquipmentByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeEquipmentByID200Response}
     */
    getRecipeEquipmentByID(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipeInformation operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeInformationCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeInformation200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Get Recipe Information
     * Use a recipe id to get full information about a recipe, such as ingredients, nutrition, diet and allergen information, etc.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.includeNutrition Include nutrition data in the recipe information. Nutrition data is per serving. If you want the nutrition data for the entire recipe, just multiply by the number of servings. (default to false)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeInformationCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeInformation200Response}
     */
    getRecipeInformation(id: number, opts: {
        includeNutrition: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipeInformationBulk operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeInformationBulkCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeInformationBulk200ResponseInner>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Get Recipe Information Bulk
     * Get information about multiple recipes at once. This is equivalent to calling the Get Recipe Information endpoint multiple times, but faster.
     * @param {String} ids A comma-separated list of recipe ids.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.includeNutrition Include nutrition data in the recipe information. Nutrition data is per serving. If you want the nutrition data for the entire recipe, just multiply by the number of servings. (default to false)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeInformationBulkCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeInformationBulk200ResponseInner>}
     */
    getRecipeInformationBulk(ids: string, opts: {
        includeNutrition: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipeIngredientsByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeIngredientsByIDCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeIngredientsByID200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Ingredients by ID
     * Get a recipe's ingredient list.
     * @param {Number} id The item's id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeIngredientsByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeIngredientsByID200Response}
     */
    getRecipeIngredientsByID(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipeNutritionWidgetByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeNutritionWidgetByIDCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeNutritionWidgetByID200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Nutrition by ID
     * Get a recipe's nutrition data.
     * @param {Number} id The item's id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeNutritionWidgetByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeNutritionWidgetByID200Response}
     */
    getRecipeNutritionWidgetByID(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipePriceBreakdownByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipePriceBreakdownByIDCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipePriceBreakdownByID200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Price Breakdown by ID
     * Get a recipe's price breakdown data.
     * @param {Number} id The item's id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipePriceBreakdownByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipePriceBreakdownByID200Response}
     */
    getRecipePriceBreakdownByID(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the getRecipeTasteByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeTasteByIDCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeTasteByID200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Taste by ID
     * Get a recipe's taste. The tastes supported are sweet, salty, sour, bitter, savory, and fatty.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/Boolean} opts.normalize Normalize to the strongest taste. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getRecipeTasteByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetRecipeTasteByID200Response}
     */
    getRecipeTasteByID(id: number, opts: {
        normalize: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the getSimilarRecipes operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~getSimilarRecipesCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:com.spoonacular.client/com.spoonacular.client.model/GetSimilarRecipes200ResponseInner>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Get Similar Recipes
     * Find recipes which are similar to the given one.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Number} opts.number The maximum number of items to return (between 1 and 100). Defaults to 10. (default to 10)
     * @param {Boolean} opts.limitLicense Whether the recipes should have an open license that allows display with proper attribution. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~getSimilarRecipesCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:com.spoonacular.client/com.spoonacular.client.model/GetSimilarRecipes200ResponseInner>}
     */
    getSimilarRecipes(id: number, opts: {
        number: number;
        limitLicense: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the guessNutritionByDishName operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~guessNutritionByDishNameCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GuessNutritionByDishName200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Guess Nutrition by Dish Name
     * Estimate the macronutrients of a dish based on its title.
     * @param {String} title The title of the dish.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~guessNutritionByDishNameCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GuessNutritionByDishName200Response}
     */
    guessNutritionByDishName(title: string, callback: any): any;
    /**
     * Callback function to receive the result of the ingredientsByIDImage operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~ingredientsByIDImageCallback
     * @param {String} error Error message, if any.
     * @param {Object} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Ingredients by ID Image
     * Visualize a recipe's ingredient list.
     * @param {Number} id The recipe id.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.measure Whether the the measures should be 'us' or 'metric'.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~ingredientsByIDImageCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Object}
     */
    ingredientsByIDImage(id: number, opts: {
        measure: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the parseIngredients operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~parseIngredientsCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:com.spoonacular.client/com.spoonacular.client.model/ParseIngredients200ResponseInner>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Parse Ingredients
     * Extract an ingredient from plain text.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.language The language of the input. Either 'en' or 'de'.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~parseIngredientsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:com.spoonacular.client/com.spoonacular.client.model/ParseIngredients200ResponseInner>}
     */
    parseIngredients(opts: {
        contentType: any;
        language: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the priceBreakdownByIDImage operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~priceBreakdownByIDImageCallback
     * @param {String} error Error message, if any.
     * @param {Object} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Price Breakdown by ID Image
     * Visualize a recipe's price breakdown.
     * @param {Number} id The recipe id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~priceBreakdownByIDImageCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Object}
     */
    priceBreakdownByIDImage(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the quickAnswer operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~quickAnswerCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/QuickAnswer200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Quick Answer
     * Answer a nutrition related natural language question.
     * @param {String} q The nutrition related question.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~quickAnswerCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/QuickAnswer200Response}
     */
    quickAnswer(q: string, callback: any): any;
    /**
     * Callback function to receive the result of the recipeNutritionByIDImage operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeNutritionByIDImageCallback
     * @param {String} error Error message, if any.
     * @param {Object} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Nutrition by ID Image
     * Visualize a recipe's nutritional information as an image.
     * @param {Number} id The recipe id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeNutritionByIDImageCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Object}
     */
    recipeNutritionByIDImage(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the recipeNutritionLabelImage operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeNutritionLabelImageCallback
     * @param {String} error Error message, if any.
     * @param {Object} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Nutrition Label Image
     * Get a recipe's nutrition label as an image.
     * @param {Number} id The recipe id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.showOptionalNutrients Whether to show optional nutrients.
     * @param {Boolean} opts.showZeroValues Whether to show zero values.
     * @param {Boolean} opts.showIngredients Whether to show a list of ingredients.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeNutritionLabelImageCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Object}
     */
    recipeNutritionLabelImage(id: number, opts: {
        showOptionalNutrients: boolean;
        showZeroValues: boolean;
        showIngredients: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the recipeNutritionLabelWidget operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeNutritionLabelWidgetCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Nutrition Label Widget
     * Get a recipe's nutrition label as an HTML widget.
     * @param {Number} id The recipe id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.defaultCss Whether the default CSS should be added to the response. (default to true)
     * @param {Boolean} opts.showOptionalNutrients Whether to show optional nutrients.
     * @param {Boolean} opts.showZeroValues Whether to show zero values.
     * @param {Boolean} opts.showIngredients Whether to show a list of ingredients.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeNutritionLabelWidgetCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    recipeNutritionLabelWidget(id: number, opts: {
        defaultCss: boolean;
        showOptionalNutrients: boolean;
        showZeroValues: boolean;
        showIngredients: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the recipeTasteByIDImage operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeTasteByIDImageCallback
     * @param {String} error Error message, if any.
     * @param {Object} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Taste by ID Image
     * Get a recipe's taste as an image. The tastes supported are sweet, salty, sour, bitter, savory, and fatty.
     * @param {Number} id The recipe id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.normalize Normalize to the strongest taste.
     * @param {String} opts.rgb Red, green, blue values for the chart color.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~recipeTasteByIDImageCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Object}
     */
    recipeTasteByIDImage(id: number, opts: {
        normalize: boolean;
        rgb: string;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the searchRecipes operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~searchRecipesCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/SearchRecipes200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Search Recipes
     * Search through hundreds of thousands of recipes using advanced filtering and ranking. NOTE: This method combines searching by query, by ingredients, and by nutrients into one endpoint.
     * @param {Object} opts Optional parameters
     * @param {String} opts.query The (natural language) search query.
     * @param {String} opts.cuisine The cuisine(s) of the recipes. One or more, comma separated (will be interpreted as 'OR'). See a full list of supported cuisines.
     * @param {String} opts.excludeCuisine The cuisine(s) the recipes must not match. One or more, comma separated (will be interpreted as 'AND'). See a full list of supported cuisines.
     * @param {String} opts.diet The diet for which the recipes must be suitable. See a full list of supported diets.
     * @param {String} opts.intolerances A comma-separated list of intolerances. All recipes returned must not contain ingredients that are not suitable for people with the intolerances entered. See a full list of supported intolerances.
     * @param {String} opts.equipment The equipment required. Multiple values will be interpreted as 'or'. For example, value could be \"blender, frying pan, bowl\".
     * @param {String} opts.includeIngredients A comma-separated list of ingredients that should/must be used in the recipes.
     * @param {String} opts.excludeIngredients A comma-separated list of ingredients or ingredient types that the recipes must not contain.
     * @param {String} opts.type The type of recipe. See a full list of supported meal types.
     * @param {Boolean} opts.instructionsRequired Whether the recipes must have instructions.
     * @param {Boolean} opts.fillIngredients Add information about the ingredients and whether they are used or missing in relation to the query.
     * @param {Boolean} opts.addRecipeInformation If set to true, you get more information about the recipes returned.
     * @param {Boolean} opts.addRecipeNutrition If set to true, you get nutritional information about each recipes returned.
     * @param {String} opts.author The username of the recipe author.
     * @param {String} opts.tags The tags (can be diets, meal types, cuisines, or intolerances) that the recipe must have.
     * @param {Number} opts.recipeBoxId The id of the recipe box to which the search should be limited to.
     * @param {String} opts.titleMatch Enter text that must be found in the title of the recipes.
     * @param {Number} opts.maxReadyTime The maximum time in minutes it should take to prepare and cook the recipe.
     * @param {Boolean} opts.ignorePantry Whether to ignore typical pantry items, such as water, salt, flour, etc. (default to false)
     * @param {String} opts.sort The strategy to sort recipes by. See a full list of supported sorting options.
     * @param {String} opts.sortDirection The direction in which to sort. Must be either 'asc' (ascending) or 'desc' (descending).
     * @param {Number} opts.minCarbs The minimum amount of carbohydrates in grams the recipe must have.
     * @param {Number} opts.maxCarbs The maximum amount of carbohydrates in grams the recipe can have.
     * @param {Number} opts.minProtein The minimum amount of protein in grams the recipe must have.
     * @param {Number} opts.maxProtein The maximum amount of protein in grams the recipe can have.
     * @param {Number} opts.minCalories The minimum amount of calories the recipe must have.
     * @param {Number} opts.maxCalories The maximum amount of calories the recipe can have.
     * @param {Number} opts.minFat The minimum amount of fat in grams the recipe must have.
     * @param {Number} opts.maxFat The maximum amount of fat in grams the recipe can have.
     * @param {Number} opts.minAlcohol The minimum amount of alcohol in grams the recipe must have.
     * @param {Number} opts.maxAlcohol The maximum amount of alcohol in grams the recipe can have.
     * @param {Number} opts.minCaffeine The minimum amount of caffeine in milligrams the recipe must have.
     * @param {Number} opts.maxCaffeine The maximum amount of caffeine in milligrams the recipe can have.
     * @param {Number} opts.minCopper The minimum amount of copper in milligrams the recipe must have.
     * @param {Number} opts.maxCopper The maximum amount of copper in milligrams the recipe can have.
     * @param {Number} opts.minCalcium The minimum amount of calcium in milligrams the recipe must have.
     * @param {Number} opts.maxCalcium The maximum amount of calcium in milligrams the recipe can have.
     * @param {Number} opts.minCholine The minimum amount of choline in milligrams the recipe must have.
     * @param {Number} opts.maxCholine The maximum amount of choline in milligrams the recipe can have.
     * @param {Number} opts.minCholesterol The minimum amount of cholesterol in milligrams the recipe must have.
     * @param {Number} opts.maxCholesterol The maximum amount of cholesterol in milligrams the recipe can have.
     * @param {Number} opts.minFluoride The minimum amount of fluoride in milligrams the recipe must have.
     * @param {Number} opts.maxFluoride The maximum amount of fluoride in milligrams the recipe can have.
     * @param {Number} opts.minSaturatedFat The minimum amount of saturated fat in grams the recipe must have.
     * @param {Number} opts.maxSaturatedFat The maximum amount of saturated fat in grams the recipe can have.
     * @param {Number} opts.minVitaminA The minimum amount of Vitamin A in IU the recipe must have.
     * @param {Number} opts.maxVitaminA The maximum amount of Vitamin A in IU the recipe can have.
     * @param {Number} opts.minVitaminC The minimum amount of Vitamin C milligrams the recipe must have.
     * @param {Number} opts.maxVitaminC The maximum amount of Vitamin C in milligrams the recipe can have.
     * @param {Number} opts.minVitaminD The minimum amount of Vitamin D in micrograms the recipe must have.
     * @param {Number} opts.maxVitaminD The maximum amount of Vitamin D in micrograms the recipe can have.
     * @param {Number} opts.minVitaminE The minimum amount of Vitamin E in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminE The maximum amount of Vitamin E in milligrams the recipe can have.
     * @param {Number} opts.minVitaminK The minimum amount of Vitamin K in micrograms the recipe must have.
     * @param {Number} opts.maxVitaminK The maximum amount of Vitamin K in micrograms the recipe can have.
     * @param {Number} opts.minVitaminB1 The minimum amount of Vitamin B1 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB1 The maximum amount of Vitamin B1 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB2 The minimum amount of Vitamin B2 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB2 The maximum amount of Vitamin B2 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB5 The minimum amount of Vitamin B5 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB5 The maximum amount of Vitamin B5 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB3 The minimum amount of Vitamin B3 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB3 The maximum amount of Vitamin B3 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB6 The minimum amount of Vitamin B6 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB6 The maximum amount of Vitamin B6 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB12 The minimum amount of Vitamin B12 in micrograms the recipe must have.
     * @param {Number} opts.maxVitaminB12 The maximum amount of Vitamin B12 in micrograms the recipe can have.
     * @param {Number} opts.minFiber The minimum amount of fiber in grams the recipe must have.
     * @param {Number} opts.maxFiber The maximum amount of fiber in grams the recipe can have.
     * @param {Number} opts.minFolate The minimum amount of folate in micrograms the recipe must have.
     * @param {Number} opts.maxFolate The maximum amount of folate in micrograms the recipe can have.
     * @param {Number} opts.minFolicAcid The minimum amount of folic acid in micrograms the recipe must have.
     * @param {Number} opts.maxFolicAcid The maximum amount of folic acid in micrograms the recipe can have.
     * @param {Number} opts.minIodine The minimum amount of iodine in micrograms the recipe must have.
     * @param {Number} opts.maxIodine The maximum amount of iodine in micrograms the recipe can have.
     * @param {Number} opts.minIron The minimum amount of iron in milligrams the recipe must have.
     * @param {Number} opts.maxIron The maximum amount of iron in milligrams the recipe can have.
     * @param {Number} opts.minMagnesium The minimum amount of magnesium in milligrams the recipe must have.
     * @param {Number} opts.maxMagnesium The maximum amount of magnesium in milligrams the recipe can have.
     * @param {Number} opts.minManganese The minimum amount of manganese in milligrams the recipe must have.
     * @param {Number} opts.maxManganese The maximum amount of manganese in milligrams the recipe can have.
     * @param {Number} opts.minPhosphorus The minimum amount of phosphorus in milligrams the recipe must have.
     * @param {Number} opts.maxPhosphorus The maximum amount of phosphorus in milligrams the recipe can have.
     * @param {Number} opts.minPotassium The minimum amount of potassium in milligrams the recipe must have.
     * @param {Number} opts.maxPotassium The maximum amount of potassium in milligrams the recipe can have.
     * @param {Number} opts.minSelenium The minimum amount of selenium in micrograms the recipe must have.
     * @param {Number} opts.maxSelenium The maximum amount of selenium in micrograms the recipe can have.
     * @param {Number} opts.minSodium The minimum amount of sodium in milligrams the recipe must have.
     * @param {Number} opts.maxSodium The maximum amount of sodium in milligrams the recipe can have.
     * @param {Number} opts.minSugar The minimum amount of sugar in grams the recipe must have.
     * @param {Number} opts.maxSugar The maximum amount of sugar in grams the recipe can have.
     * @param {Number} opts.minZinc The minimum amount of zinc in milligrams the recipe must have.
     * @param {Number} opts.maxZinc The maximum amount of zinc in milligrams the recipe can have.
     * @param {Number} opts.offset The number of results to skip (between 0 and 900).
     * @param {Number} opts.number The maximum number of items to return (between 1 and 100). Defaults to 10. (default to 10)
     * @param {Boolean} opts.limitLicense Whether the recipes should have an open license that allows display with proper attribution. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~searchRecipesCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/SearchRecipes200Response}
     */
    searchRecipes(opts: {
        query: string;
        cuisine: string;
        excludeCuisine: string;
        diet: string;
        intolerances: string;
        equipment: string;
        includeIngredients: string;
        excludeIngredients: string;
        type: string;
        instructionsRequired: boolean;
        fillIngredients: boolean;
        addRecipeInformation: boolean;
        addRecipeNutrition: boolean;
        author: string;
        tags: string;
        recipeBoxId: number;
        titleMatch: string;
        maxReadyTime: number;
        ignorePantry: boolean;
        sort: string;
        sortDirection: string;
        minCarbs: number;
        maxCarbs: number;
        minProtein: number;
        maxProtein: number;
        minCalories: number;
        maxCalories: number;
        minFat: number;
        maxFat: number;
        minAlcohol: number;
        maxAlcohol: number;
        minCaffeine: number;
        maxCaffeine: number;
        minCopper: number;
        maxCopper: number;
        minCalcium: number;
        maxCalcium: number;
        minCholine: number;
        maxCholine: number;
        minCholesterol: number;
        maxCholesterol: number;
        minFluoride: number;
        maxFluoride: number;
        minSaturatedFat: number;
        maxSaturatedFat: number;
        minVitaminA: number;
        maxVitaminA: number;
        minVitaminC: number;
        maxVitaminC: number;
        minVitaminD: number;
        maxVitaminD: number;
        minVitaminE: number;
        maxVitaminE: number;
        minVitaminK: number;
        maxVitaminK: number;
        minVitaminB1: number;
        maxVitaminB1: number;
        minVitaminB2: number;
        maxVitaminB2: number;
        minVitaminB5: number;
        maxVitaminB5: number;
        minVitaminB3: number;
        maxVitaminB3: number;
        minVitaminB6: number;
        maxVitaminB6: number;
        minVitaminB12: number;
        maxVitaminB12: number;
        minFiber: number;
        maxFiber: number;
        minFolate: number;
        maxFolate: number;
        minFolicAcid: number;
        maxFolicAcid: number;
        minIodine: number;
        maxIodine: number;
        minIron: number;
        maxIron: number;
        minMagnesium: number;
        maxMagnesium: number;
        minManganese: number;
        maxManganese: number;
        minPhosphorus: number;
        maxPhosphorus: number;
        minPotassium: number;
        maxPotassium: number;
        minSelenium: number;
        maxSelenium: number;
        minSodium: number;
        maxSodium: number;
        minSugar: number;
        maxSugar: number;
        minZinc: number;
        maxZinc: number;
        offset: number;
        number: number;
        limitLicense: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the searchRecipesByIngredients operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~searchRecipesByIngredientsCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:com.spoonacular.client/com.spoonacular.client.model/SearchRecipesByIngredients200ResponseInner>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Search Recipes by Ingredients
     *  Ever wondered what recipes you can cook with the ingredients you have in your fridge or pantry? This endpoint lets you find recipes that either maximize the usage of ingredients you have at hand (pre shopping) or minimize the ingredients that you don't currently have (post shopping).
     * @param {Object} opts Optional parameters
     * @param {String} opts.ingredients A comma-separated list of ingredients that the recipes should contain.
     * @param {Number} opts.number The maximum number of items to return (between 1 and 100). Defaults to 10. (default to 10)
     * @param {Boolean} opts.limitLicense Whether the recipes should have an open license that allows display with proper attribution. (default to true)
     * @param {Number} opts.ranking Whether to maximize used ingredients (1) or minimize missing ingredients (2) first.
     * @param {Boolean} opts.ignorePantry Whether to ignore typical pantry items, such as water, salt, flour, etc. (default to false)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~searchRecipesByIngredientsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:com.spoonacular.client/com.spoonacular.client.model/SearchRecipesByIngredients200ResponseInner>}
     */
    searchRecipesByIngredients(opts: {
        ingredients: string;
        number: number;
        limitLicense: boolean;
        ranking: number;
        ignorePantry: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the searchRecipesByNutrients operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~searchRecipesByNutrientsCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:com.spoonacular.client/com.spoonacular.client.model/SearchRecipesByNutrients200ResponseInner>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Search Recipes by Nutrients
     * Find a set of recipes that adhere to the given nutritional limits. You may set limits for macronutrients (calories, protein, fat, and carbohydrate) and/or many micronutrients.
     * @param {Object} opts Optional parameters
     * @param {Number} opts.minCarbs The minimum amount of carbohydrates in grams the recipe must have.
     * @param {Number} opts.maxCarbs The maximum amount of carbohydrates in grams the recipe can have.
     * @param {Number} opts.minProtein The minimum amount of protein in grams the recipe must have.
     * @param {Number} opts.maxProtein The maximum amount of protein in grams the recipe can have.
     * @param {Number} opts.minCalories The minimum amount of calories the recipe must have.
     * @param {Number} opts.maxCalories The maximum amount of calories the recipe can have.
     * @param {Number} opts.minFat The minimum amount of fat in grams the recipe must have.
     * @param {Number} opts.maxFat The maximum amount of fat in grams the recipe can have.
     * @param {Number} opts.minAlcohol The minimum amount of alcohol in grams the recipe must have.
     * @param {Number} opts.maxAlcohol The maximum amount of alcohol in grams the recipe can have.
     * @param {Number} opts.minCaffeine The minimum amount of caffeine in milligrams the recipe must have.
     * @param {Number} opts.maxCaffeine The maximum amount of caffeine in milligrams the recipe can have.
     * @param {Number} opts.minCopper The minimum amount of copper in milligrams the recipe must have.
     * @param {Number} opts.maxCopper The maximum amount of copper in milligrams the recipe can have.
     * @param {Number} opts.minCalcium The minimum amount of calcium in milligrams the recipe must have.
     * @param {Number} opts.maxCalcium The maximum amount of calcium in milligrams the recipe can have.
     * @param {Number} opts.minCholine The minimum amount of choline in milligrams the recipe must have.
     * @param {Number} opts.maxCholine The maximum amount of choline in milligrams the recipe can have.
     * @param {Number} opts.minCholesterol The minimum amount of cholesterol in milligrams the recipe must have.
     * @param {Number} opts.maxCholesterol The maximum amount of cholesterol in milligrams the recipe can have.
     * @param {Number} opts.minFluoride The minimum amount of fluoride in milligrams the recipe must have.
     * @param {Number} opts.maxFluoride The maximum amount of fluoride in milligrams the recipe can have.
     * @param {Number} opts.minSaturatedFat The minimum amount of saturated fat in grams the recipe must have.
     * @param {Number} opts.maxSaturatedFat The maximum amount of saturated fat in grams the recipe can have.
     * @param {Number} opts.minVitaminA The minimum amount of Vitamin A in IU the recipe must have.
     * @param {Number} opts.maxVitaminA The maximum amount of Vitamin A in IU the recipe can have.
     * @param {Number} opts.minVitaminC The minimum amount of Vitamin C in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminC The maximum amount of Vitamin C in milligrams the recipe can have.
     * @param {Number} opts.minVitaminD The minimum amount of Vitamin D in micrograms the recipe must have.
     * @param {Number} opts.maxVitaminD The maximum amount of Vitamin D in micrograms the recipe can have.
     * @param {Number} opts.minVitaminE The minimum amount of Vitamin E in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminE The maximum amount of Vitamin E in milligrams the recipe can have.
     * @param {Number} opts.minVitaminK The minimum amount of Vitamin K in micrograms the recipe must have.
     * @param {Number} opts.maxVitaminK The maximum amount of Vitamin K in micrograms the recipe can have.
     * @param {Number} opts.minVitaminB1 The minimum amount of Vitamin B1 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB1 The maximum amount of Vitamin B1 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB2 The minimum amount of Vitamin B2 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB2 The maximum amount of Vitamin B2 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB5 The minimum amount of Vitamin B5 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB5 The maximum amount of Vitamin B5 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB3 The minimum amount of Vitamin B3 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB3 The maximum amount of Vitamin B3 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB6 The minimum amount of Vitamin B6 in milligrams the recipe must have.
     * @param {Number} opts.maxVitaminB6 The maximum amount of Vitamin B6 in milligrams the recipe can have.
     * @param {Number} opts.minVitaminB12 The minimum amount of Vitamin B12 in micrograms the recipe must have.
     * @param {Number} opts.maxVitaminB12 The maximum amount of Vitamin B12 in micrograms the recipe can have.
     * @param {Number} opts.minFiber The minimum amount of fiber in grams the recipe must have.
     * @param {Number} opts.maxFiber The maximum amount of fiber in grams the recipe can have.
     * @param {Number} opts.minFolate The minimum amount of folate in micrograms the recipe must have.
     * @param {Number} opts.maxFolate The maximum amount of folate in micrograms the recipe can have.
     * @param {Number} opts.minFolicAcid The minimum amount of folic acid in micrograms the recipe must have.
     * @param {Number} opts.maxFolicAcid The maximum amount of folic acid in micrograms the recipe can have.
     * @param {Number} opts.minIodine The minimum amount of iodine in micrograms the recipe must have.
     * @param {Number} opts.maxIodine The maximum amount of iodine in micrograms the recipe can have.
     * @param {Number} opts.minIron The minimum amount of iron in milligrams the recipe must have.
     * @param {Number} opts.maxIron The maximum amount of iron in milligrams the recipe can have.
     * @param {Number} opts.minMagnesium The minimum amount of magnesium in milligrams the recipe must have.
     * @param {Number} opts.maxMagnesium The maximum amount of magnesium in milligrams the recipe can have.
     * @param {Number} opts.minManganese The minimum amount of manganese in milligrams the recipe must have.
     * @param {Number} opts.maxManganese The maximum amount of manganese in milligrams the recipe can have.
     * @param {Number} opts.minPhosphorus The minimum amount of phosphorus in milligrams the recipe must have.
     * @param {Number} opts.maxPhosphorus The maximum amount of phosphorus in milligrams the recipe can have.
     * @param {Number} opts.minPotassium The minimum amount of potassium in milligrams the recipe must have.
     * @param {Number} opts.maxPotassium The maximum amount of potassium in milligrams the recipe can have.
     * @param {Number} opts.minSelenium The minimum amount of selenium in micrograms the recipe must have.
     * @param {Number} opts.maxSelenium The maximum amount of selenium in micrograms the recipe can have.
     * @param {Number} opts.minSodium The minimum amount of sodium in milligrams the recipe must have.
     * @param {Number} opts.maxSodium The maximum amount of sodium in milligrams the recipe can have.
     * @param {Number} opts.minSugar The minimum amount of sugar in grams the recipe must have.
     * @param {Number} opts.maxSugar The maximum amount of sugar in grams the recipe can have.
     * @param {Number} opts.minZinc The minimum amount of zinc in milligrams the recipe must have.
     * @param {Number} opts.maxZinc The maximum amount of zinc in milligrams the recipe can have.
     * @param {Number} opts.offset The number of results to skip (between 0 and 900).
     * @param {Number} opts.number The maximum number of items to return (between 1 and 100). Defaults to 10. (default to 10)
     * @param {Boolean} opts.random If true, every request will give you a random set of recipes within the requested limits.
     * @param {Boolean} opts.limitLicense Whether the recipes should have an open license that allows display with proper attribution. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~searchRecipesByNutrientsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:com.spoonacular.client/com.spoonacular.client.model/SearchRecipesByNutrients200ResponseInner>}
     */
    searchRecipesByNutrients(opts: {
        minCarbs: number;
        maxCarbs: number;
        minProtein: number;
        maxProtein: number;
        minCalories: number;
        maxCalories: number;
        minFat: number;
        maxFat: number;
        minAlcohol: number;
        maxAlcohol: number;
        minCaffeine: number;
        maxCaffeine: number;
        minCopper: number;
        maxCopper: number;
        minCalcium: number;
        maxCalcium: number;
        minCholine: number;
        maxCholine: number;
        minCholesterol: number;
        maxCholesterol: number;
        minFluoride: number;
        maxFluoride: number;
        minSaturatedFat: number;
        maxSaturatedFat: number;
        minVitaminA: number;
        maxVitaminA: number;
        minVitaminC: number;
        maxVitaminC: number;
        minVitaminD: number;
        maxVitaminD: number;
        minVitaminE: number;
        maxVitaminE: number;
        minVitaminK: number;
        maxVitaminK: number;
        minVitaminB1: number;
        maxVitaminB1: number;
        minVitaminB2: number;
        maxVitaminB2: number;
        minVitaminB5: number;
        maxVitaminB5: number;
        minVitaminB3: number;
        maxVitaminB3: number;
        minVitaminB6: number;
        maxVitaminB6: number;
        minVitaminB12: number;
        maxVitaminB12: number;
        minFiber: number;
        maxFiber: number;
        minFolate: number;
        maxFolate: number;
        minFolicAcid: number;
        maxFolicAcid: number;
        minIodine: number;
        maxIodine: number;
        minIron: number;
        maxIron: number;
        minMagnesium: number;
        maxMagnesium: number;
        minManganese: number;
        maxManganese: number;
        minPhosphorus: number;
        maxPhosphorus: number;
        minPotassium: number;
        maxPotassium: number;
        minSelenium: number;
        maxSelenium: number;
        minSodium: number;
        maxSodium: number;
        minSugar: number;
        maxSugar: number;
        minZinc: number;
        maxZinc: number;
        offset: number;
        number: number;
        random: boolean;
        limitLicense: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the summarizeRecipe operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~summarizeRecipeCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/SummarizeRecipe200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Summarize Recipe
     * Automatically generate a short description that summarizes key information about the recipe.
     * @param {Number} id The item's id.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~summarizeRecipeCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/SummarizeRecipe200Response}
     */
    summarizeRecipe(id: number, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeEquipment operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeEquipmentCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Equipment Widget
     * Visualize the equipment used to make a recipe.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.accept Accept header.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeEquipmentCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeEquipment(opts: {
        contentType: any;
        accept: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizePriceBreakdown operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizePriceBreakdownCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Price Breakdown Widget
     * Visualize the price breakdown of a recipe.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.accept Accept header.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.language The language of the input. Either 'en' or 'de'.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizePriceBreakdownCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizePriceBreakdown(opts: {
        contentType: any;
        accept: any;
        language: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipeEquipmentByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeEquipmentByIDCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Equipment by ID Widget
     * Visualize a recipe's equipment list.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.defaultCss Whether the default CSS should be added to the response. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeEquipmentByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipeEquipmentByID(id: number, opts: {
        defaultCss: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipeIngredientsByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeIngredientsByIDCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Ingredients by ID Widget
     * Visualize a recipe's ingredient list.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.defaultCss Whether the default CSS should be added to the response. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.measure Whether the the measures should be 'us' or 'metric'.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeIngredientsByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipeIngredientsByID(id: number, opts: {
        defaultCss: boolean;
        measure: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipeNutrition operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeNutritionCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Nutrition Widget
     * Visualize a recipe's nutritional information as HTML including CSS.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.accept Accept header.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.language The language of the input. Either 'en' or 'de'.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeNutritionCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipeNutrition(opts: {
        contentType: any;
        accept: any;
        language: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipeNutritionByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeNutritionByIDCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Nutrition by ID Widget
     * Visualize a recipe's nutritional information as HTML including CSS.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.defaultCss Whether the default CSS should be added to the response. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.accept Accept header.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeNutritionByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipeNutritionByID(id: number, opts: {
        defaultCss: boolean;
        accept: any;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipePriceBreakdownByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipePriceBreakdownByIDCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Price Breakdown by ID Widget
     * Visualize a recipe's price breakdown.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.defaultCss Whether the default CSS should be added to the response. (default to true)
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipePriceBreakdownByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipePriceBreakdownByID(id: number, opts: {
        defaultCss: boolean;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipeTaste operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeTasteCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Taste Widget
     * Visualize a recipe's taste information as HTML including CSS. You can play around with that endpoint!
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.language The language of the input. Either 'en' or 'de'.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.contentType The content type.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/String} opts.accept Accept header.
     * @param {Boolean} opts.normalize Whether to normalize to the strongest taste.
     * @param {String} opts.rgb Red, green, blue values for the chart color.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeTasteCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipeTaste(opts: {
        language: any;
        contentType: any;
        accept: any;
        normalize: boolean;
        rgb: string;
    }, callback: any): any;
    /**
     * Callback function to receive the result of the visualizeRecipeTasteByID operation.
     * @callback module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeTasteByIDCallback
     * @param {String} error Error message, if any.
     * @param {String} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Recipe Taste by ID Widget
     * Get a recipe's taste. The tastes supported are sweet, salty, sour, bitter, savory, and fatty.
     * @param {Number} id The item's id.
     * @param {Object} opts Optional parameters
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/Boolean} opts.normalize Whether to normalize to the strongest taste. (default to true)
     * @param {String} opts.rgb Red, green, blue values for the chart color.
     * @param {module:com.spoonacular.client/com.spoonacular/RecipesApi~visualizeRecipeTasteByIDCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link String}
     */
    visualizeRecipeTasteByID(id: number, opts: {
        normalize: any;
        rgb: string;
    }, callback: any): any;
}
