"use strict";
/**
 * spoonacular API
 * The spoonacular Nutrition, Recipe, and Food API allows you to access over 380,000 recipes, thousands of ingredients, 800,000 food products, and 100,000 menu items. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.  Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.
 *
 * The version of the OpenAPI document: 1.1
 * Contact: mail@spoonacular.com
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 *
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ApiClient_1 = __importDefault(require("../ApiClient"));
const GetDishPairingForWine200Response_1 = __importDefault(require("../com.spoonacular.client.model/GetDishPairingForWine200Response"));
const GetWineDescription200Response_1 = __importDefault(require("../com.spoonacular.client.model/GetWineDescription200Response"));
const GetWinePairing200Response_1 = __importDefault(require("../com.spoonacular.client.model/GetWinePairing200Response"));
const GetWineRecommendation200Response_1 = __importDefault(require("../com.spoonacular.client.model/GetWineRecommendation200Response"));
/**
* Wine service.
* @module com.spoonacular.client/com.spoonacular/WineApi
* @version 1.1
*/
class WineApi {
    /**
    * Constructs a new WineApi.
    * @alias module:com.spoonacular.client/com.spoonacular/WineApi
    * @class
    * @param {module:com.spoonacular.client/ApiClient} [apiClient] Optional API client implementation to use,
    * default to {@link module:com.spoonacular.client/ApiClient#instance} if unspecified.
    */
    constructor(apiClient) {
        this.apiClient = apiClient || ApiClient_1.default.instance;
    }
    /**
     * Callback function to receive the result of the getDishPairingForWine operation.
     * @callback module:com.spoonacular.client/com.spoonacular/WineApi~getDishPairingForWineCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetDishPairingForWine200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Dish Pairing for Wine
     * Find a dish that goes well with a given wine.
     * @param {String} wine The type of wine that should be paired, e.g. \"merlot\", \"riesling\", or \"malbec\".
     * @param {module:com.spoonacular.client/com.spoonacular/WineApi~getDishPairingForWineCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetDishPairingForWine200Response}
     */
    getDishPairingForWine(wine, callback) {
        let postBody = null;
        // verify the required parameter 'wine' is set
        if (wine === undefined || wine === null) {
            throw new Error("Missing the required parameter 'wine' when calling getDishPairingForWine");
        }
        let pathParams = {};
        let queryParams = {
            'wine': wine
        };
        let headerParams = {};
        let formParams = {};
        let authNames = ['apiKeyScheme'];
        let contentTypes = [];
        let accepts = ['application/json'];
        let returnType = GetDishPairingForWine200Response_1.default;
        return this.apiClient.callApi('/food/wine/dishes', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getWineDescription operation.
     * @callback module:com.spoonacular.client/com.spoonacular/WineApi~getWineDescriptionCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetWineDescription200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Wine Description
     * Get a simple description of a certain wine, e.g. \"malbec\", \"riesling\", or \"merlot\".
     * @param {String} wine The name of the wine that should be paired, e.g. \"merlot\", \"riesling\", or \"malbec\".
     * @param {module:com.spoonacular.client/com.spoonacular/WineApi~getWineDescriptionCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetWineDescription200Response}
     */
    getWineDescription(wine, callback) {
        let postBody = null;
        // verify the required parameter 'wine' is set
        if (wine === undefined || wine === null) {
            throw new Error("Missing the required parameter 'wine' when calling getWineDescription");
        }
        let pathParams = {};
        let queryParams = {
            'wine': wine
        };
        let headerParams = {};
        let formParams = {};
        let authNames = ['apiKeyScheme'];
        let contentTypes = [];
        let accepts = ['application/json'];
        let returnType = GetWineDescription200Response_1.default;
        return this.apiClient.callApi('/food/wine/description', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getWinePairing operation.
     * @callback module:com.spoonacular.client/com.spoonacular/WineApi~getWinePairingCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetWinePairing200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Wine Pairing
     * Find a wine that goes well with a food. Food can be a dish name (\"steak\"), an ingredient name (\"salmon\"), or a cuisine (\"italian\").
     * @param {String} food The food to get a pairing for. This can be a dish (\"steak\"), an ingredient (\"salmon\"), or a cuisine (\"italian\").
     * @param {Object} opts Optional parameters
     * @param {Number} opts.maxPrice The maximum price for the specific wine recommendation in USD.
     * @param {module:com.spoonacular.client/com.spoonacular/WineApi~getWinePairingCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetWinePairing200Response}
     */
    getWinePairing(food, opts, callback) {
        opts = opts || {};
        let postBody = null;
        // verify the required parameter 'food' is set
        if (food === undefined || food === null) {
            throw new Error("Missing the required parameter 'food' when calling getWinePairing");
        }
        let pathParams = {};
        let queryParams = {
            'food': food,
            'maxPrice': opts['maxPrice']
        };
        let headerParams = {};
        let formParams = {};
        let authNames = ['apiKeyScheme'];
        let contentTypes = [];
        let accepts = ['application/json'];
        let returnType = GetWinePairing200Response_1.default;
        return this.apiClient.callApi('/food/wine/pairing', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
    /**
     * Callback function to receive the result of the getWineRecommendation operation.
     * @callback module:com.spoonacular.client/com.spoonacular/WineApi~getWineRecommendationCallback
     * @param {String} error Error message, if any.
     * @param {module:com.spoonacular.client/com.spoonacular.client.model/GetWineRecommendation200Response} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */
    /**
     * Wine Recommendation
     * Get a specific wine recommendation (concrete product) for a given wine type, e.g. \"merlot\".
     * @param {String} wine The type of wine to get a specific product recommendation for.
     * @param {Object} opts Optional parameters
     * @param {Number} opts.maxPrice The maximum price for the specific wine recommendation in USD.
     * @param {Number} opts.minRating The minimum rating of the recommended wine between 0 and 1. For example, 0.8 equals 4 out of 5 stars.
     * @param {Number} opts.number The number of wine recommendations expected (between 1 and 100). (default to 10)
     * @param {module:com.spoonacular.client/com.spoonacular/WineApi~getWineRecommendationCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:com.spoonacular.client/com.spoonacular.client.model/GetWineRecommendation200Response}
     */
    getWineRecommendation(wine, opts, callback) {
        opts = opts || {};
        let postBody = null;
        // verify the required parameter 'wine' is set
        if (wine === undefined || wine === null) {
            throw new Error("Missing the required parameter 'wine' when calling getWineRecommendation");
        }
        let pathParams = {};
        let queryParams = {
            'wine': wine,
            'maxPrice': opts['maxPrice'],
            'minRating': opts['minRating'],
            'number': opts['number']
        };
        let headerParams = {};
        let formParams = {};
        let authNames = ['apiKeyScheme'];
        let contentTypes = [];
        let accepts = ['application/json'];
        let returnType = GetWineRecommendation200Response_1.default;
        return this.apiClient.callApi('/food/wine/recommendation', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null, callback);
    }
}
exports.default = WineApi;
